# Filename:     tb_full_adder.do
# Filetype:     Modelsim Script File
# Date:         1 oct 2013
# Update:       11 jan 2022
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Lab
# Error:        -
# Version:      1.4
# Copyright:    (c)2022, De Haagse Hogeschool

# Transcript on, we see output
transcript on

# Recreate working directory
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Loop through all the VHDL files and compile them
foreach vhd_file [ glob *.vhd ] {
	#puts $vhd_file
	vcom -93 -work work $vhd_file
}

# Start the simulator
vsim -t 1ns -L rtl_work -L work -voptargs="+acc" full_adder

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
add list -nodelta -label SW8 sw8
add list -nodelta -label SW7 sw7
add list -nodelta -label SW6 sw6
add list -nodelta -label SW5 sw5
add list -nodelta -width 3 -label SW4 sw4
add list -nodelta -label SW3 sw3
add list -nodelta -label SW2 sw2
add list -nodelta -label SW1 sw1
add list -nodelta -width 3 -label SW0 sw0
add list -nodelta -width 5 -label LEDR4 ledr4
add list -nodelta -label LEDR3 ledr3
add list -nodelta -label LEDR2 ledr2
add list -nodelta -label LEDR1 ledr1
add list -nodelta -label LEDR0 ledr0

add list -nodelta -width 5 -label B -unsigned {B {SW8 SW7 SW6 SW5}}
add list -nodelta -width 3 -label A -unsigned {A {SW4 SW3 SW2 SW1}}
add list -nodelta -width 3 -label C0 -unsigned SW0
add list -nodelta -width 3 -label C4 -unsigned LEDR4
add list -nodelta -width 3 -label S -unsigned {S {LEDR3 LEDR2 LEDR1 LEDR0}}
add list -nodelta -width 3 -label C4_S -unsigned {C4_S {LEDR4 LEDR3 LEDR2 LEDR1 LEDR0}}
add list -nodelta -width 3 -label V ledr9

# Open List window
noview Wave
noview Signals
noview Structure
view list

# Apply stimuli
force SW0 0 0, 1 20   -repeat 40    -cancel 10240
force SW1 0 0, 1 40   -repeat 80    -cancel 10240
force SW2 0 0, 1 80   -repeat 160   -cancel 10240
force SW3 0 0, 1 160  -repeat 320   -cancel 10240
force SW4 0 0, 1 320  -repeat 640   -cancel 10240
force SW5 0 0, 1 640  -repeat 1280  -cancel 10240
force SW6 0 0, 1 1280 -repeat 2560  -cancel 10240
force SW7 0 0, 1 2560 -repeat 5120  -cancel 10240
force SW8 0 0, 1 5120 -repeat 10240 -cancel 10240


# Run simulation for 10220 ns
run 10220 ns
